@@ -5,6 +5,7 @@ This module offers a set of operations that user can modify their excel files.
 import os
 import pathlib
 import warnings
+from pathlib import Path
 
 try:
     from importlib.resources import files
@@ -31,7 +32,7 @@ warnings.simplefilter(action="ignore", category=UserWarning)
 
 
 def read_excel_file(
-    file: str,
+    file: "str | Path",
     excel_definition: Exceldefinition,
     sprint_schedule: SprintScheduleStore,
 ) -> tuple:
@@ -57,7 +58,9 @@ def read_excel_file(
     if not pathlib.Path(file).exists():
         raise ValueError(f"The input excel file: {file} cannot be found.")
 
-    wb = openpyxl.load_workbook(file)
+    wb = openpyxl.load_workbook(
+        str(file), read_only=True, keep_vba=False, data_only=True, keep_links=True
+    )
     sheet = wb.active
 
     # The count of column is taking from the definition file to avoid too many columns inside the excel file.
@@ -77,6 +80,7 @@ def read_excel_file(
         if len(columns) > 0:
             break
         for cell in cells:
+            # TODO: Copy styles
             columns.append(cell.value)
 
     start_cell = "A2"
@@ -136,10 +140,10 @@ def output_to_csv_file(
 
 
 def output_to_excel_file(
-    file: str,
+    file: "str | Path",
     stories: "list[Story]",
     excel_definition: Exceldefinition,
-    columns_in_excel: "list[str]" = None,
+    columns_in_excel: "list[str] | None" = None,
     over_write: bool = True,
 ):
     """
@@ -165,7 +169,11 @@ def output_to_excel_file(
 
     if pathlib.Path(file).exists():
         if over_write is True:
-            os.remove(file)
+            try:
+                os.remove(file)
+            except PermissionError as e:
+                print(e)
+                return
         else:
             raise ValueError(f"The output excel file: {file} is already exist.")
 
@@ -191,15 +199,15 @@ def output_to_excel_file(
                 cell = sheet.cell(row=row_index + 2, column=column_index)
                 cell.value = stories[row_index].format_value(column_name)
 
-    wb.save(file)
+    wb.save(str(file))
     wb.close()
 
 
 def process_excel_file(
-    input_file: str,
-    output_file: str,
-    excel_definition_config: str = None,
-    sprint_schedule_config: str = None,
+    input_file: "str | Path",
+    output_file: "str | Path",
+    excel_definition_config: "str | None" = None,
+    sprint_schedule_config: "str | None" = None,
     over_write: bool = True,
 ):
     """
@@ -242,9 +250,14 @@ def process_excel_file(
 
     validation_result = excel_definition.validate()
     if len(validation_result) != 0:
+        print(
+            "Validating excel definition failed. Please check below information to fix."
+        )
         for item in validation_result:
             print(item)
         return
+    else:
+        print("Validating excel definition success.")
 
     excel_columns, stories = read_excel_file(
         input_file, excel_definition, sprint_schedule
